#
# spec file for package python-visvis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-visvis
Version:        1.14.0
Release:        5.2
Summary:        An object oriented approach to visualization of 1D to 4D data
License:        BSD-3-Clause
URL:            https://github.com/almarklein/visvis
Source:         https://files.pythonhosted.org/packages/source/v/visvis/visvis-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#almarklein/visvis#128
Patch0:         use-importlib.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-opengl
Requires:       python-qt5
Recommends:     python-Pillow
Recommends:     python-imageio
Recommends:     python-scikit-image
Recommends:     python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module imageio}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module scikit-image}
# /SECTION
%python_subpackages

%description
Visvis is a Python library for visualization of 1D to 4D data in an
object oriented way. Essentially, visvis is an object oriented layer
of Python on top of OpenGl. A Matlab/Matplotlib-like interface in the
form of a set of functions allows creation of objects (e.g. plot(),
imshow(), volshow(), surf()).

%prep
%autosetup -p1 -n visvis-%{version}
find * -name '*.py' -exec sed -i -e '/^#!\//, 1d' {} \;

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license license.txt
%{python_sitelib}/visvis
%{python_sitelib}/visvis-%{version}.dist-info

%changelog
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2
* Wed Jul 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2 for now.
* Wed Mar 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Replace use-importlib.patch with one that has been submitted upstream.
* Wed Mar 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Add patch use-importlib.patch: Use importlib machinery, not the imp
  module.
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.14.0:
  * Python 3.6/3.7 support dropped
  * PySide6 support
* Thu Feb 18 2021 Ben Greiner <code@bnavigator.de>
- update to 1.13.0
  * Add support for Python 3.9
- skip python36 build: with Numpy 1.20, python36-numpy is no longer
  available on Tumbleweed (NEP 29)
* Fri Jul 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.12.4
  * tests included in sdist
  * minor bugfixes
* Sat Dec 21 2019 Todd R <toddrme2178@gmail.com>
- Disable python2 due to dependency disabling python2 support
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- initial version
